
![](docs/assets/images/cylinter-logo.svg)

## An Interactive Image Segmentation Filter for Multiplex Microscopy.

CyLinter is quality control software for identifying and removing cell segmentation instances corrupted by optical and/or image-processing artifacts in multiplex microscopy images. The tool is user-guided and comprises a set of modular and extensible QC modules instantiated in a configurable [Python](https://www.python.org) Class object. Module results are cached to allow for dynamic restarts.

CyLinter development is led by [Greg Baker](https://github.com/gjbaker) at the [Laboratory of Systems Pharmacology](https://hits.harvard.edu/the-program/laboratory-of-systems-pharmacology/about/), Harvard Medical School.

**Funding:** This work is supported by the following:

* *NCI grant U2C-CA233262: Pre-cancer Atlases of Cutaneous and Hematologic Origin*
* *NIH grant U54CA225088: Systems Pharmacology of Therapeutic and Adverse Responses to Immune Checkpoint and Small Molecule Drugs*
* *Ludwig Center at Harvard Medical School and the Ludwig Cancer Research Foundation*

**Instructions:** https://labsyspharm.github.io/cylinter/
